import sys

from yaml_extender.cli import main

if __name__ == "__main__":
    sys.exit(main())
